@@ -19,6 +19,7 @@
 import os
 import importlib
 import subprocess
+from tempfile import mkdtemp
 
 import pytest
 from path import path
@@ -165,12 +166,13 @@ def get_rabbit_path(name):
 
 
 @pytest.fixture
-def rabbitmq(request, tmpdir):
+def rabbitmq(request):
     pika, config = try_import('pika', request)
 
     rabbit_conf = open(request.config.getvalue('rabbit_conf')).readlines()
     rabbit_conf = dict(line[:-1].split('=') for line in rabbit_conf)
 
+    tmpdir = path(mkdtemp('rabbitmq_fixture'))
     rabbit_conf['RABBITMQ_LOG_BASE'] = str(tmpdir)[:64]
     rabbit_conf['RABBITMQ_MNESIA_BASE'] = str(tmpdir)[:64]
 
